@@ -1,9 +1,10 @@
+import io
 import os
 import struct
-import pandas as pd
-import numpy
 from tempfile import NamedTemporaryFile
 
+import numpy
+import pandas as pd
 import pytest
 from conftest import odc_modules
 
@@ -49,6 +50,54 @@ def test_normal_constant_string():
     _check_decode(cdc, encoded, "helloAAA")
 
 
+def check_codec_choice(testdata, expected_codec):
+    # Check that the correct codec is being selected
+    series = pd.Series(testdata)
+    selected_codec = codec.select_codec("column", series, DataType.STRING, False)
+    assert isinstance(selected_codec, expected_codec)
+
+    # Create a temporary stream
+    f = io.BytesIO()
+    st = LittleEndianStream(f)
+
+    # Encode the header and data for just this column
+    selected_codec.encode_header(st)
+    for val in testdata:
+        selected_codec.encode(st, val)
+    st.seek(0)  # reset the stream to the start
+
+    # Check the header can be decoded correctly
+    decoded_codec = codec.read_codec(st)
+    assert decoded_codec.column_name == "column"
+    assert decoded_codec.type == DataType.STRING
+    assert decoded_codec.name == selected_codec.name
+
+    # Check the encoded data matches
+    for val in testdata:
+        decoded_val = selected_codec.decode(st)
+        assert val == decoded_val
+
+
+def test_string_codec_selection():
+    # Deliberately using strings on length 7,8,9 to catch edges cases
+    testcases = [
+        [["constan", "constan"], codec.ConstantString],
+        [["constant", "constant"], codec.ConstantString],
+        [["longconst", "longconst"], codec.Int8String],
+        [["longconstant", "longconstant"], codec.Int8String],
+        [["not", "constant", "longnotconstant"], codec.Int8String],
+        [["longconstant"] + [str(num) for num in range(256)], codec.Int16String],
+    ]
+
+    for testdata, expected_codec in testcases:
+        check_codec_choice(testdata, expected_codec)
+
+    os.environ["ODC_ENABLE_WRITING_LONG_STRING_CODEC"] = "true"
+    for testdata, expected_codec in testcases[2:3]:
+        check_codec_choice(testdata, codec.LongConstantString)
+    del os.environ["ODC_ENABLE_WRITING_LONG_STRING_CODEC"]
+
+
 @pytest.mark.parametrize("odyssey", odc_modules)
 def test_decode_odb1_missing_strings(odyssey):
     """
@@ -72,7 +121,7 @@ def test_decode_odb1_missing_strings(odyssey):
         assert v == ""
 
 
-# Each case is a single column and the expected codec 
+# Each case is a single column and the expected codec
 testcases = [
     [["abcd"] * 7, codec.ConstantString],
     [["abcdefghi"] * 7, codec.Int8String],
@@ -80,6 +129,7 @@ testcases = [
     [["longconstant"] + [str(num) for num in range(256)], codec.Int16String],
 ]
 
+
 @pytest.mark.parametrize("encoder", odc_modules)
 @pytest.mark.parametrize("decoder", odc_modules)
 @pytest.mark.parametrize("testcase", testcases)
@@ -90,11 +140,11 @@ def test_new_strings(encoder, decoder, testcase, type):
     the older way of storing strings as objects both work
     """
     testcase, codec = testcase
-    df = pd.DataFrame(testcase, dtype = type)
+    df = pd.DataFrame(testcase, dtype=type)
 
     with NamedTemporaryFile() as fencode:
         encoder.encode_odb(df, fencode.name)
-        round_tripped_data = decoder.read_odb(fencode.name, single = True)
+        round_tripped_data = decoder.read_odb(fencode.name, single=True)
 
     # Check the data round tripped
-    numpy.testing.assert_array_equal(df.iloc[0].values, round_tripped_data.iloc[0].values)
\ No newline at end of file
+    numpy.testing.assert_array_equal(df.iloc[0].values, round_tripped_data.iloc[0].values)
